@@ -21,7 +21,7 @@ from botocore.compat import copy_kwargs, OrderedDict
 
 from awscli import EnvironmentVariables, __version__
 from awscli.formatter import get_formatter
-from awscli.paramfile import get_paramfile
+from awscli.paramfile import get_paramfile, ResourceLoadingError
 from awscli.plugin import load_plugins
 from awscli.argparser import MainArgParser
 from awscli.argparser import ServiceArgParser
@@ -38,6 +38,9 @@ LOG = logging.getLogger('awscli.clidriver')
 class UnknownArgumentError(Exception):
     pass
 
+class BadArgumentError(Exception):
+    pass
+
 
 def main():
     driver = create_clidriver()
@@ -111,7 +114,6 @@ class CLIDriver(object):
         return commands
 
     def _build_argument_table(self):
-        LOG.debug('_build_argument_table')
         argument_table = OrderedDict()
         cli_data = self._get_cli_data()
         cli_arguments = cli_data.get('options', None)
@@ -134,7 +136,6 @@ class CLIDriver(object):
             argument_object.add_to_arg_table(argument_table)
         # Then the final step is to send out an event so handlers
         # can add extra arguments or modify existing arguments.
-        LOG.debug('_build_argument_table_again')
         self.session.emit('building-top-level-params',
                           argument_table=argument_table)
         return argument_table
@@ -273,8 +274,6 @@ class ServiceCommand(CLICommand):
         command_table = OrderedDict()
         service_object = self._get_service_object()
         for operation_object in service_object.operations:
-            LOG.debug(operation_object)
-            LOG.debug('operation.name=%s' % operation_object.name)
             cli_name = xform_name(operation_object.name, '-')
             command_table[cli_name] = ServiceOperation(
                 name=cli_name,
@@ -527,7 +526,6 @@ class CLIArgument(BaseCLIArgument):
 
         """
         cli_name = self.cli_name
-        LOG.debug('add_to_parser: %s' % cli_name)
         parser.add_argument(
             cli_name,
             help=self.documentation,
@@ -550,8 +548,10 @@ class CLIArgument(BaseCLIArgument):
             # just associating the key and value in the params dict as down
             # below.  Sometimes this can be more complicated, and subclasses
             # can customize as they need.
-            LOG.debug('add_to_params: %s' % self.py_name)
-            parameters[self.argument_object.py_name] = self._unpack_argument(value)
+            unpacked = self._unpack_argument(value)
+            LOG.debug('Unpacked value of "%s" for parameter "%s": %s', value,
+                      self.argument_object.py_name, unpacked)
+            parameters[self.argument_object.py_name] = unpacked
 
     def _unpack_argument(self, value):
         if not hasattr(self.argument_object, 'no_paramfile'):
@@ -573,13 +573,19 @@ class CLIArgument(BaseCLIArgument):
 
     def _handle_param_file(self, value):
         session = self.operation_object.service.session
+        # If the arg is suppose to be a list type, just
+        # get the first element in the list, as it may
+        # refer to a file:// (or http/https) type.
+        potential_param_value = value
         if isinstance(value, list) and len(value) == 1:
-            temp = value[0]
-        else:
-            temp = value
-        temp = get_paramfile(session, temp)
-        if temp:
-            value = temp
+            potential_param_value = value[0]
+        try:
+            actual_value = get_paramfile(session, potential_param_value)
+        except ResourceLoadingError as e:
+            raise BadArgumentError(
+                "Bad value for argument '%s': %s" % (self.cli_name, e))
+        if actual_value is not None:
+            value = actual_value
         return value
 
     def _emit(self, name, **kwargs):
@@ -674,7 +680,6 @@ class ServiceOperation(object):
 
     def __init__(self, name, operation_object, operation_caller,
                  service_object):
-        LOG.debug('creating ServiceOperation: %s' % name)
         self._arg_table = None
         self._name = name
         self._operation_object = operation_object
@@ -701,6 +706,11 @@ class ServiceOperation(object):
         if remaining:
             raise UnknownArgumentError(
                 "Unknown options: %s" % ', '.join(remaining))
+        service_name = self._service_object.endpoint_prefix
+        operation_name = self._operation_object.name
+        event = 'operation-args-parsed.%s.%s' % (service_name,
+                                                 operation_name)
+        self._emit(event, parsed_args=parsed_args)
         call_parameters = self._build_call_parameters(parsed_args,
                                                       self.arg_table)
         return self._operation_caller.invoke(
@@ -771,7 +781,9 @@ class CLIOperationCaller(object):
         self._session = session
 
     def invoke(self, operation_object, parameters, parsed_globals):
-        endpoint = operation_object.service.get_endpoint(parsed_globals.region)
+        endpoint = operation_object.service.get_endpoint(
+            region_name=parsed_globals.region,
+            endpoint_url=parsed_globals.endpoint_url)
         endpoint.verify = not parsed_globals.no_verify_ssl
         if operation_object.can_paginate and parsed_globals.paginate:
             pages = operation_object.paginate(endpoint, **parameters)
